rnalysis.filtering.FoldChangeFilter.filter\_by\_attribute
=========================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: FoldChangeFilter.filter_by_attribute